**optasoccer is a Python library for reading opta soccer data.**

## Installation
```bash
pip install optasoccer
```

## Quick start

```python
from optasoccer import read_f24
events, matches = read_24()
```
